/*
   Unix SMB/Netbios implementation.
   Version 1.9.
   Copyright (C) Andrew Tridgell 1994-1997

   This file is part of the port to OpenVMS
   VMS specific definitions, part 1
   Copyright (C) Eckart Meyer 1996-1997

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 02-Jun-1998	J. Malmberg	Adapted for GCC and CMU-IP

*/
/*	vms1.h
 *
 * Definitions
 */

 /* Get the information from SETUP.COM into the build */
/*---------------------------------------------------*/
#ifdef __GNUC__
#include "conf.h"
#endif

#define NO_RESOURCEH
#define NO_SYSMOUNTH

#ifndef __GNUC__
#define NO_GRPH
#define NO_SYSPARAMH
#endif

#define MAXHOSTNAMELEN  64

 /* can't put more than 64KB through a socket per read/write */
/*----------------------------------------------------------*/
#define SOCKET_WRITE_LIMIT 0xFFFF

 /* fcntl() not yet implemented, this disables it in includes.h */
/*-------------------------------------------------------------*/
#define HAVE_FCNTL_LOCK 0
#define SIGCLD_IGNORE
#define NO_SIGNAL_TEST

#ifndef __GNUC__  /* I thought this was also in DEC C */
#define const
#endif

 /* not need in VMS 7.0 and up, unless using GNU C 2.8.1 headers */
/*--------------------------------------------------------------*/
#if __CRTL_VER < 70000000 || defined(_VMS_V6_SOURCE) || defined(__GNUC__)
#include "posixtim.h"
#else
#define lstat  stat
#define utime vms_utime
#endif



/*
 * RTL routines not present or not present in all DECC/VAXC implementation.
 * We use our own routines then.
 * To prevent DECC from prefixing those routines which *are* implemented
 * meanwhile with DECC$ we give them our own prefix.
 * Especially VMS V7 has much more routines built in. For compatibility
 * reasons we'll not use them currently.
 */

/* Note that Digital offers the AACRTL060 kit to bring the DEC C RTL for
** OpenVMS 5.5-2 systems.  The kit includes the instructions that must be
** followed to distribute it with an application.  It does not appear to be
** posted on the WWW.
**
** This kit will reduce the number of missing RTL routines
**
** The GNU C experimental build uses this run time library on OpenVMS 5.5-2
*/

/* UID_T hack.  GNU and older DEC C RTL define it as 16 bits, need 32 bits */
#if 0
#ifdef __GNUC__
#define _UID_T
#define _UID_T_
typedef unsigned long uid_t;
#endif
#endif

 /* The DEC C setuid does nothing according to documentation */
/*----------------------------------------------------------*/
#define setuid vms_setuid

#define __unix_getuid vms_getuid
#ifdef __GNUC__
#define getuid vms_getuid
#endif

 /* These may need special name mangling */
/*--------------------------------------*/
#define __unix_getcwd vms_getcwd
#define delete vms_delete
#define rename vms_rename
#define mkdir vms_mkdir
#define chmod vms_chmod

#define ftruncate vms_ftruncate

#define getpwuid vms_getpwuid
#define getpwnam vms_getpwnam

#define getpwent vms_getpwent
#define setpwent vms_setpwent
#define endpwent vms_endpwent

#ifndef __GNUC__
#define getlogin vms_getlogin
#endif

 /* These are required for special name mangling */
/*----------------------------------------------*/
/* Now using different name mangling */
#define opendir vms_opendir
#define closedir vms_closedir
#define readdir vms_readdir
#define rewinddir vms_rewinddir

#ifndef __GNUC__
/* A good way to kill the DECC Optimizer */
#define strdup vms_strdup
#endif

#ifndef __GNUC__  /* Use the LIBERTY version for GCC */
#define getopt vms_getopt
#endif

 /* Name Mangling need this */
/*-------------------------*/
#define rmdir vms_rmdir

#define getgrnam vms_getgrnam
#define getgrgid vms_getgrgid
#define getgroups vms_getgroups
#define getgrent vms_getgrent

#define statfs vms_statfs

#define setgroups vms_setgroups
#define initgroups vms_initgroups
#define waitpid vms_waitpid
#ifndef fcntl
#define fcntl vms_fcntl
#endif


#ifndef __GNUC__
#define optarg vms_optarg
#define optind vms_optind
#define optopt vms_optopt
#define opterr vms_opterr
#endif


#define fork   vfork
#if 0
#define tzname vms_tzname
#define daylight vms_daylight
#define timezone vms_timezone
#endif
#define unlink vms_delete
/*
 * For the following we must use our own implementation regardless
 * of RTL-Support, since we add some functionality.
 */
#define system vms_system
#define open stm_open

#ifndef __GNUC__
#define close stm_close
#define read stm_read
#define lseek stm_lseek
#endif

/*
 * Since the VMS linker converts symbols to uppercase, we need
 * to redefine samba's own definitions
 */

#define OpenDir samba_opendir
#define CloseDir samba_closedir
#define TellDir samba_telldir
#define SeekDir samba_seekdir
#define ReadDirName readdirname2
#define StrCpy samba_strcpy
#define StrnCpy samba_strncpy
#define StrCaseCmp samba_strcasecmp
#define StrnCaseCmp samba_strncasecmp
#define Abort samba_abort
#define Realloc samba_realloc
#define MemMove samba_memmove
#define ChDir samba_chdir
#define LocalTime samba_localtime
#define GetTimeOfDay samba_gettimeofday
#define TimeLocal samba_timelocal
#define TimeZone samba_timezone
#define global_machine_pasword_needs_changing gbl_m_pswd_needs_changing

/*
 * Call stat.h here, since we use our local modified version here for
 * a changed ino_t typedef.
 * So must be called before types.h (which also defines ino_t).
 *
 * Then include what's missing in DEC-C. Should also be called before
 * types.h
 */
#include <stat.h>

#ifndef __GNUC__
#include "incl.h"
#else

 /* Get password routine */
/*----------------------*/
char *getpass(const char *__prompt);
#endif

#include <longfile_vms.h>
