/*
   Unix SMB/Netbios implementation.
   Version 1.9.
   Copyright (C) Andrew Tridgell 1994-1997

   This file is part of the port to OpenVMS
   VMS specific definitions, part 2
   Copyright (C) Eckart Meyer 1996-1997

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
/*	vms2.h
 *
 * includes, some additional prototypes and other misc stuff
 */
/* 03-Jul-1998	J. Malmberg	GCC and CMU IP stuff */

#include <arpa/inet.h>
#include <fcntl.h>

 /* rewinddir is defined in GCC headers */
/*-------------------------------------*/
#ifdef __GNUC__
#ifdef rewinddir
#undef rewinddir
#endif
#endif

#include <dirent.h>

 /* Put rewinddir back */
/*--------------------*/
#ifdef __GNUC__
#ifdef rewinddir
#undef rewinddir
#define rewinddir vms_rewinddir
#endif
#endif

#include <string.h>
#include <unistd.h>

#ifndef __GNUC__
#include "vfs.h"
#include "param.h"
#include "grp.h"
#else
#include <timeb.h>	/* for struct timeval */
#include <socket.h>
#include <sys/param.h>
#include <grp.h>
#include <sys/vfs.h>
#endif


#ifndef __GNUC__
#if __VMS_VER < 70000000
int strcasecmp(char * __s, char * __t);
#endif
#else
#include <strings.h>
#endif

#ifndef __GNUC__
int statfs(char * __path, struct statfs * __buf);
#endif

char *crypt(char * __key, char * __salt);

#ifndef __GNUC__
char *mktemp(char * __buf);
#endif

/* int gettimeofday(struct timeval * __tv, struct timezone * __timezone);*/ /**/
int gettimeofday(struct timeval * __tv, void * __timezone); /**/

int chroot(char * __path);

#ifndef __GNUCC__
int getopt(int __argc, char * const __argv[], const char * __optstring);
#else
#include <getopt.h>
#endif

int initgroups(char * __name, gid_t __basegid);

struct group *vms_getgrgid(gid_t gid);

#ifndef __GNUCC__
pid_t vms_waitpid(pid_t pid, int *stat, int options);
#endif

int setgroups(int __ngroups, gid_t __gidset[]);

int vms_process_exists(const unsigned long pid);
#define SIGNAL_CAST (void (*)(int))
#ifndef bzero
#define bzero(a,n)    memset(a,0,n)
#endif
#define chroot chdir	/* don't know how to implement chroot ... */
#ifndef __GNUC__
#define NOSTRDUP
#endif

/* socket definitions */


 /* for V4 of DECC compiler #define SELECT_CAST (int *)  GCC needs this too */
/*-------------------------------------------------------------------------*/
/* #define SELECT_CAST (fd_set *) */

#ifndef __GNUC__
#define TCP_NODELAY 1	/* test this ! */
#endif

/* definitions for VMS file name mangling */

#if 0
char *VMSMakeFilename(char * __vms_buf, char * __file_spec);
char *vms_make_name(char * __name);
#endif
char *vms_get_name(char * __name);
#if 0
#define chdir(__path) chdir(vms_make_name(__path))
#define chmod(__name, __mode) chmod(VMSMakeFilename(NULL,__name), __mode)
#define fopen(__path, __mode) fopen(vms_make_name(__path), __mode)
#endif
/* strerror crashes with unknown error codes - it does not know 'vms-error'!
   also, older C RTL versions don't know about ENOTEMPTY */
#ifndef ENOTEMPTY
#define ENOTEMPTY 66
#endif
#define strerror(__errno) ( (__errno == EVMSERR) ? "VMS error" : ( \
		(__errno == ENOTEMPTY) ? "Directory not empty" : \
		strerror(__errno)) )

#ifndef __GNUC__
#define NOSTRCASECMP
#endif
#define NO_STRFTIME	/* strftime is obviously not working */
#define NO_GET_BROADCAST
#define NO_GETSPNAM
#define NO_EID
#define USE_WAITPID
#define USE_GETCWD
#define USE_SETSID
#define USE_SYSTEM 1			/* in UID.C for smbrun */
#define NO_FORK_DEBUG			/* server.c and util.c */
#define FTRUNCATE_CAN_EXTEND 1		/* util.c */

 /* Make sure that FALSE is defined */
/*---------------------------------*/
#ifdef __GNUC__
#ifndef FALSE
#define FALSE 0
#endif
#ifndef TRUE
#define TRUE 1
#endif
#endif
